@@ -36,14 +36,16 @@ class Job:
 	@classmethod
 	def jobs(cls):
 		url = f'{API_URL}/jobs'
-		response = requests.get(url, headers=self.headers)
+		headers = {API_KEY_HEADER: API_KEY} # TODO cls.headers?
+		response = requests.get(url, headers=headers)
 		# TODO cast into Job(s)?
 		return response.json()
 
 	@classmethod
 	def job(cls, uuid):
 		url = f'{API_URL}/jobs/{uuid}'
-		response = requests.get(url, headers=self.headers)
+		headers = {API_KEY_HEADER: API_KEY} # TODO cls.headers?
+		response = requests.get(url, headers=headers)
 		# TODO cast into Job?
 		return response.json()
 
